@@ -210,19 +210,6 @@ out:
         return ret;
 }
 
-gboolean
-gsd_power_is_hardware_a_tablet (void)
-{
-        char *type;
-        gboolean ret = FALSE;
-
-        type = gnome_settings_get_chassis_type ();
-        ret = (g_strcmp0 (type, "tablet") == 0);
-        g_free (type);
-
-        return ret;
-}
-
 /* This timer goes off every few minutes, whether the user is idle or not,
    to try and clean up anything that has gone wrong.
 
@@ -303,10 +290,10 @@ gsd_power_enable_screensaver_watchdog (void)
         /* Make sure that Xorg's DPMS extension never gets in our
          * way. The defaults are now applied in Fedora 20 from
          * being "0" by default to being "600" by default */
-        gdk_error_trap_push ();
+        gdk_x11_display_error_trap_push (gdk_display_get_default ());
         if (DPMSQueryExtension(GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), &dummy, &dummy))
                 DPMSSetTimeouts (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), 0, 0, 0);
-        gdk_error_trap_pop_ignored ();
+        gdk_x11_display_error_trap_pop_ignored (gdk_display_get_default ());
         id = g_timeout_add_seconds (XSCREENSAVER_WATCHDOG_TIMEOUT,
                                     disable_builtin_screensaver,
                                     NULL);
